my.pewma <- 
  function(formula,data,omega){
    # Extract variables
    model0 <- model.frame(formula, data)
    Y <- model.extract(model0, "response")
    X <- as.matrix(model.matrix(formula, data))[,-1]
    
    # Fukumoto adds only this part
     init <- c(omega, glm(Y ~ X, data=data, family=poisson)$coef[-1])
     names(init) <- c("omega",colnames(X))
    
    # Our estimates using R
     fit <- Pewma(y=Y, x=X, init.param=init)

    # Output list
    out <- list()
    out$coefficients <- fit$coef
    rownames(out$coefficients) <- c("omega",colnames(X))
    out$par <- fit$par
    names(out$par) <- rownames(out$coefficients)
    out$hessian <- fit$hessian
    rownames(out$hessian) <- colnames(out$hessian) <- names(out$par)
    out$omega <- fit$par[1]
    out$delta <- fit$par[2:length(fit$par)]
    out$aic <- -2 * fit$llf + 2 * length(fit$par)
    out$Y <- Y
    out$X <- X
    invisible(out)
    }

my.par <- 
  function(formula,data,p){
    # Extract variables
    model0 <- model.frame(formula, data)
    Y <- model.extract(model0, "response")
    X <- as.matrix(model.matrix(formula, data))
    colnames(X)[1] <- "(Intercept)"

    # Fukumoto adds only this part
    init <- c(rep(0, p), glm(Y ~ X[,-1], data=data, family=poisson)$coef)
    names(init) <- c(paste("rho","",1:p,sep=""),colnames(X))

    # Our estimates using R
    fit <- Parp(y=Y, x=X, init.param=init)

    # Output list
    out <-list()
    out$coefficients <- fit$coef
    rownames(out$coefficients) <- c(paste("rho","",1:p,sep=""),colnames(X))
    out$par <- fit$par
    names(out$par) <- rownames(out$coefficients)
    out$hessian <- fit$hessian
    rownames(out$hessian) <- colnames(out$hessian) <- names(out$par)
    out$rho <- fit$par[1:p]
    out$delta <- fit$par[(p+1):length(fit$par)]
    out$aic <- -2 * fit$llf + 2 * length(fit$par)
    out$Y <- Y
    out$X <- X
    out$p <- p
    invisible(out)
    }
